@@ -1,7 +1,10 @@
 import json
 import os
+import re
 import subprocess
 
+from . import constants
+
 
 def set_repo_version(repo, version):
     with open(repo.get_metadata_path('version'), 'w') as out:
@@ -10,15 +13,19 @@ def set_repo_version(repo, version):
 
 def migration_0002(repo):
     """ Creates shadow repository used for storing remote values """
-    subprocess.check_call((
-        'git',
-        'clone',
-        '--shared',
-        repo.get_metadata_path('git'),
-        os.path.join(
-            repo.get_metadata_path('shadow')
-        )
-    ))
+    subprocess.check_call(
+        (
+            'git',
+            'clone',
+            '--shared',
+            '-q',
+            repo.get_metadata_path('git'),
+            os.path.join(
+                repo.get_metadata_path('shadow')
+            )
+        ),
+        stdout=subprocess.PIPE,
+    )
     repo.run_git_command('checkout', '-b', 'jira', shadow=True)
     repo.run_git_command('commit', '--allow-empty', '-m', 'Shadow Created')
     repo.run_git_command('push', 'origin', 'jira', shadow=True)
@@ -61,3 +68,15 @@ def migration_0004(repo):
     repo.run_git_command('push', 'origin', 'jira', shadow=True)
     repo.run_git_command('merge', 'jira')
     set_repo_version(repo, 4)
+
+
+def migration_0005(repo):
+    """ Dummy migration for RST->Jira format change.
+
+    Note: TicketFolders older than version 5 cannot be upgraded past
+    version 5; although I had written a migration for this originally,
+    there were a few hard-to-work-around bugs that I decided were
+    not quite important enough.
+
+    """
+    set_repo_version(repo, 5)
