@@ -58,18 +58,19 @@ class TestTicketFolder(BaseTestCase):
         self.mock_jira.issue.return_value = self.rehydrate_issue(
             'basic.issue.json'
         )
-        self.mock_get_jira = lambda: self.mock_jira
+        self.mock_get_jira = lambda _: self.mock_jira
 
         with patch(
             'jirafs.ticketfolder.TicketFolder.get_remotely_changed'
         ) as get_remotely_changed:
             get_remotely_changed.return_value = []
             self.ticketfolder = TicketFolder.clone(
-                os.path.join(
+                ticket_url='http://arbitrary.com/browse/ALPHA-123',
+                jira=self.mock_get_jira,
+                path=os.path.join(
                     self.root_folder,
                     self.arbitrary_ticket_number,
                 ),
-                jira=self.mock_get_jira
             )
 
     def test_cloned_issue_successfully(self):
